#!/usr/bin/env python

"""Tests for `p2.loader` package."""

import json
import unittest
from datetime import date

from p2.Loader import Resource
from p2.tools.driver import get_driver
from p2.tools.prepare_db import setUpDB, tearDownDB
from p2.tools.json import serializable


class TestP2Loader(unittest.TestCase):
    """Tests for `p2.loader` package."""

    def setUp(self):
        setUpDB()

    def tearDown(self):
        tearDownDB()

    def test_resource(self):
        r = Resource(
            layer='k8',
            kind='org',
            name='org 1',
            profile={
                'creation_date': date(year=2000, month=1, day=1)
            },
            children=[
                Resource(
                    layer='k8',
                    name='res 2',
                    kind='region',
                    profile={
                        'creation_date': date(year=2000, month=1, day=1)
                    }
                )
            ])
        r_serialized = serializable(r)
        self.assertEqual(r_serialized['children'][0]['name'], 'res 2')

    def test_fake_driver(self):
        org = Resource(
            name = 'org 1',
            kind = 'org',
            layer= 'fake',
            tag  = 'a tag'
        )
        params = {'root': org}
        driver = get_driver(
            driver='fake',
            module='p2.loader',
            class_name='Loader',
            **params
        )
        self.assertIsNotNone(driver)
        driver.get_resources()
        self.assertIsNotNone(driver.root)
        driver.sync_resources()
